@@ -197,48 +197,56 @@ pub fn pack_or_pack_index(
                 pack::index::traverse::Algorithm::DeltaTreeLookup
             }
         });
-    let mut progress = bundle.index.traverse(
-        &bundle.pack,
-        progress,
-        {
-            let object_path = object_path.map(|p| p.as_ref().to_owned());
-            move || {
-                let out = OutputWriter::new(object_path.clone(), sink_compress);
-                let object_verifier = if verify {
-                    object_path.as_ref().map(loose::Store::at)
-                } else {
-                    None
-                };
-                let mut read_buf = Vec::new();
-                move |object_kind, buf, index_entry, progress| {
-                    let written_id = out
-                        .write_buf(object_kind, buf, hash::Kind::Sha1)
-                        .map_err(|err| Error::Write(Box::new(err) as Box<dyn std::error::Error + Send + Sync>, object_kind, index_entry.oid))?;
-                    if written_id != index_entry.oid {
-                        if let object::Kind::Tree = object_kind {
-                            progress.info(format!("The tree in pack named {} was written as {} due to modes 100664 and 100640 rewritten as 100644.", index_entry.oid, written_id));
-                        } else {
-                            return Err(Error::ObjectEncodeMismatch(object_kind, index_entry.oid, written_id));
+    let mut progress = bundle
+        .index
+        .traverse(
+            &bundle.pack,
+            progress,
+            {
+                let object_path = object_path.map(|p| p.as_ref().to_owned());
+                move || {
+                    let out = OutputWriter::new(object_path.clone(), sink_compress);
+                    let object_verifier = if verify { object_path.as_ref().map(loose::Store::at) } else { None };
+                    let mut read_buf = Vec::new();
+                    move |object_kind, buf, index_entry, progress| {
+                        let written_id = out.write_buf(object_kind, buf, hash::Kind::Sha1).map_err(|err| {
+                            Error::Write(
+                                Box::new(err) as Box<dyn std::error::Error + Send + Sync>,
+                                object_kind,
+                                index_entry.oid,
+                            )
+                        })?;
+                        if written_id != index_entry.oid {
+                            if let object::Kind::Tree = object_kind {
+                                progress.info(format!(
+                                    "The tree in pack named {} was written as {} due to modes 100664 and 100640 rewritten as 100644.",
+                                    index_entry.oid, written_id
+                                ));
+                            } else {
+                                return Err(Error::ObjectEncodeMismatch(object_kind, index_entry.oid, written_id));
+                            }
                         }
+                        if let Some(verifier) = object_verifier.as_ref() {
+                            let obj = verifier
+                                .try_find(written_id, &mut read_buf)
+                                .map_err(|err| Error::WrittenFileCorrupt(err, written_id))?
+                                .ok_or(Error::WrittenFileMissing(written_id))?;
+                            obj.verify_checksum(written_id)?;
+                        }
+                        Ok(())
                     }
-                    if let Some(verifier) = object_verifier.as_ref() {
-                        let obj = verifier.try_find(written_id, &mut read_buf)
-                            .map_err(|err| Error::WrittenFileCorrupt(err, written_id))?
-                            .ok_or(Error::WrittenFileMissing(written_id))?;
-                        obj.verify_checksum(written_id)?;
-                    }
-                    Ok(())
                 }
-            }
-        },
-        pack::cache::lru::StaticLinkedList::<64>::default,
-        pack::index::traverse::Options {
-            algorithm,
-            thread_limit,
-            check: check.into(),
-            should_interrupt
-        },
-    ).map(|(_, _, c)| progress::DoOrDiscard::from(c)).with_context(|| "Failed to explode the entire pack - some loose objects may have been created nonetheless")?;
+            },
+            pack::cache::lru::StaticLinkedList::<64>::default,
+            pack::index::traverse::Options {
+                algorithm,
+                thread_limit,
+                check: check.into(),
+                should_interrupt,
+            },
+        )
+        .map(|(_, _, c)| progress::DoOrDiscard::from(c))
+        .with_context(|| "Failed to explode the entire pack - some loose objects may have been created nonetheless")?;
 
     let (index_path, data_path) = (bundle.index.path().to_owned(), bundle.pack.path().to_owned());
     drop(bundle);
